//
//  MultitaskingTestAppDelegate.m
//  MultitaskingTest
//

#import "MultitaskingTestAppDelegate.h"
#import "MultitaskingTestViewController.h"

#define MessageBodyKey @"EVENTKEY1"
#define MessageTitleKey @"MSGKEY1"

@implementation MultitaskingTestAppDelegate

@synthesize window;
@synthesize viewController;

//////////////////////////////////////////////////////////////////
//アプリ起動
//////////////////////////////////////////////////////////////////
- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions {    
    
    [window addSubview:viewController.view];
	[window makeKeyAndVisible];
    return YES;
}


//////////////////////////////////////////////////////////////////
//
//////////////////////////////////////////////////////////////////
- (void)applicationWillResignActive:(UIApplication *)application {
/*
Sent when the application is about to move from active to inactive state. This can occur for certain types of temporary interruptions (such as an incoming phone call or SMS message) or when the user quits the application and it begins the transition to the background state.
Use this method to pause ongoing tasks, disable timers, and throttle down OpenGL ES frame rates. Games should use this method to pause the game.
*/
}


//////////////////////////////////////////////////////////////////
// ローカル通知
//////////////////////////////////////////////////////////////////
- (void)application:(UIApplication *)application didReceiveLocalNotification:(UILocalNotification *)notification
{
	// アラートを出す
	NSString *itemName = [notification.userInfo objectForKey:MessageBodyKey];
	NSString *messageTitle = [notification.userInfo objectForKey:MessageTitleKey];
	UIAlertView* alertView = [[UIAlertView alloc] initWithTitle:messageTitle message:itemName delegate:self cancelButtonTitle:@"OK" otherButtonTitles:nil];
	[alertView show];
	[alertView release];
}


//////////////////////////////////////////////////////////////////
//バックグラウンドに入る
//////////////////////////////////////////////////////////////////
- (void)applicationDidEnterBackground:(UIApplication *)application {
	
	//スケジュールを全クリア
	[[UIApplication sharedApplication] cancelAllLocalNotifications];
	
	//アラーム用のスケジュールDateを作る
	NSDate *now = [NSDate date];
	NSDate *scheduled = [now dateByAddingTimeInterval:10];// 10秒後
	
	//アプリ再起動後に表示するアラートに渡す辞書
	NSDictionary *infoDict = [NSDictionary dictionaryWithObjectsAndKeys:
							  @"おかえり",MessageBodyKey, 
							  @"ローカル通知完了", MessageTitleKey, nil];
	
	[self setScheduleLocalNotification:scheduled							//スケジュールのDate
							 alertBody:@"スケジュールの時間です"					//アラートの本文メッセージ
						   alertAction:@"アプリ起動"							//アプリを再起動するためのボタンのタイトル
							 soundName:UILocalNotificationDefaultSoundName	//再生するサウンドの名前
							  infoDict:infoDict];
	
	//アプリをバックグラウンドで動かすため
	backgroundTask = [application beginBackgroundTaskWithExpirationHandler:
						  ^{
							  [application endBackgroundTask:backgroundTask];
						  }
					  ];
	 
}


//////////////////////////////////////////////////////////////////
//アプリケーションがフォアグランドになる
//////////////////////////////////////////////////////////////////
- (void)applicationWillEnterForeground:(UIApplication *)application {
	//application.applicationIconBadgeNumber = 0;
}


//////////////////////////////////////////////////////////////////
//アプリケーションがアクティブになる
//////////////////////////////////////////////////////////////////
- (void)applicationDidBecomeActive:(UIApplication *)application {
/*
Restart any tasks that were paused (or not yet started) while the application was inactive. If the application was previously in the background, optionally refresh the user interface.
*/
}

//////////////////////////////////////////////////////////////////
//アプリケーションが終了する
//////////////////////////////////////////////////////////////////
- (void)applicationWillTerminate:(UIApplication *)application {
	
}

//////////////////////////////////////////////////////////////////
//
//////////////////////////////////////////////////////////////////
- (void)applicationDidReceiveMemoryWarning:(UIApplication *)application {
/*
Free up as much memory as possible by purging cached data objects that can be recreated (or reloaded from disk) later.
*/
}

//////////////////////////////////////////////////////////////////
//解放
//////////////////////////////////////////////////////////////////
- (void)dealloc {
    [viewController release];
    [window release];
    [super dealloc];
}


#pragma mark -


//////////////////////////////////////////////////////////////////
//LocalNotificationにスケジュールを設定する
//////////////////////////////////////////////////////////////////
- (UILocalNotification*)setScheduleLocalNotification:(NSDate*)scDate	//スケジュールのDate
						   alertBody:(NSString*)bodyStr					//アラートの本文メッセージ
						 alertAction:(NSString*)actStr					//アプリを再起動するためのボタンのタイトル
						   soundName:(NSString*)soundName				//再生するサウンドの名前
							infoDict:(NSDictionary*)infoDict			//
{
	UILocalNotification *localNotif = [[UILocalNotification alloc] init];
	if (localNotif){
		localNotif.fireDate = scDate;
		localNotif.timeZone = [NSTimeZone defaultTimeZone];
		localNotif.alertBody = bodyStr;
		localNotif.alertAction = actStr;
		localNotif.soundName = soundName;
		localNotif.userInfo = infoDict;
		//localNotif.applicationIconBadgeNumber = 1;
		[[UIApplication sharedApplication] scheduleLocalNotification:localNotif];
	}
	
	return	[localNotif autorelease];
}


@end


